@@ -238,15 +238,10 @@ class RedisDao(object):
         """
         向名为set_name的hash队列中添加一个键值对
         """
-        if isinstance(value, (dict, list)):
-            value = json.dumps(value)
         self.db.hset(set_name, key, value)
 
     def hget(self, set_name, key):
         """
         从名为set_name的hash队列中获取一个键值对
         """
-        value = self.db.hset(set_name, key)
-        if isinstance(value, (dict, list)):
-            value = json.loads(value)
-        return value
+        return self.db.hget(set_name, key)
